@@ -82,7 +82,7 @@
 #' reported information. See \code{\link{oecalc}} for more information.
 #' 
 #' For frequentist meta-analysis, within-study variation can either be modeled using a Normal (\code{model.oe = "normal/log"} 
-#' or \code{model.oe = "normal/identity"}) or a Poisson distribution (\code{model.oe = "normal/log"}). 
+#' or \code{model.oe = "normal/identity"}) or a Poisson distribution (\code{model.oe = "poisson/log"}). 
 #' 
 #' When performing a Bayesian meta-analysis, all data are modeled using a one-stage random effects (hierarchical related regression) model.
 #' In particular, a binomial distribution (if \code{O}, \code{E} and \code{N} is known), a Poisson distribution 
@@ -91,16 +91,16 @@
 #' }
 #' 
 #' \subsection{Bayesian meta-analysis}{
-#' All Bayesian meta-analysis models assume random effects by default. Results are based on the posterior median. 
+#' All Bayesian meta-analysis models assume the presence of random effects. Summary estimates are based on the posterior mean. 
 #' Credibility and prediction intervals are directly obtained from the corresponding posterior quantiles.
 #' 
-#' The prior distribution for the (transformed) summary estimate is always modeled using a Normal distribution, 
-#' with mean \code{hp.mu.mean} (defaults to 0) and variance 
-#' \code{hp.mu.var} (defaults to 1000). For meta-analysis of the total O:E ratio, the maximum value for \code{hp.mu.var} is 100.
+#' The prior distribution for the (transformed) performance estimate is modeled using a Normal distribution, 
+#' with mean \code{hp.mu.mean} (defaults to 0) and variance \code{hp.mu.var} (defaults to 1000). 
+#' For meta-analysis of the total O:E ratio, the maximum value for \code{hp.mu.var} is 100.
 #' 
 #' By default, the prior distribution for the between-study standard deviation is modeled using a uniform distribution 
-#' (\code{hp.tau.dist="dunif"}), with boundaries \code{hp.tau.min} and \code{hp.tau.max}. Alternatively, it is possible
-#' to specify a truncated Student-t distribution (\code{hp.tau.dist="dhalft"}) with a mean of \code{hp.tau.mean}, 
+#' (\code{hp.tau.dist="dunif"}), with boundaries \code{hp.tau.min} and \code{hp.tau.max}. Alternative choices are a 
+#' truncated Student-t distribution (\code{hp.tau.dist="dhalft"}) with a mean of \code{hp.tau.mean}, 
 #' a standard deviation of \code{hp.tau.sigma} and \code{hp.tau.df} degrees of freedom. This distribution is again 
 #' restricted to the range \code{hp.tau.min} to \code{hp.tau.max}.
 #' }
@@ -156,7 +156,7 @@
 #' valmeta(cstat=c.index,  N=n, O=n.events, slab=Study, data=EuroSCORE)
 #' 
 #' # Two-stage meta-analysis of the total O:E ratio (random effects)
-#' valmeta(measure="OE", O=n.events, E=e.events, N=n, data=EuroSCORE)    
+#' valmeta(measure="OE", O=n.events, E=e.events, N=n, slab=Study, data=EuroSCORE)    
 #' valmeta(measure="OE", O=n.events, E=e.events, data=EuroSCORE)       
 #' valmeta(measure="OE", Po=Po, Pe=Pe, N=n, data=EuroSCORE)
 #' 
@@ -199,6 +199,7 @@
 #' @export
 #' @import metafor
 #' @import mvtnorm
+#' @importFrom dplyr select mutate %>%
 #' @importFrom lme4 glmer
 #' @importFrom stats coef coefficients dnorm glm nobs optim pchisq qnorm qt pt rnorm runif confint poisson
 #' predict vcov as.formula formula model.frame model.frame.default update.formula family
@@ -460,21 +461,19 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
       }
       
       out$fit <- fit
-      
       out$numstudies <- fit$k
+      out$data <- ds
     } else {
-      bayesma <- run_Bayesian_REMA(list(theta = ds$theta,
-                                        theta.var = ds$theta.se**2,
-                                        Nstudies = length(ds$theta)), 
-                                   pars = pars.default, 
-                                   FUN_generate_bugs = .generateBugsCstat,
-                                   n.chains = n.chains, 
-                                   verbose = verbose, ...) 
-      out <- c(out, bayesma)
-      class(out) <- "valmeta"
+      return(run_Bayesian_REMA(call = match.call(),
+                               measure = measure,
+                               method = method,
+                               data = ds, 
+                               pars = pars.default, 
+                               FUN_generate_bugs = .generateBugsCstat,
+                               n.chains = n.chains, 
+                               verbose = verbose, ...))
     }
     
-    out$data <- ds
     return(out)
   }
   #######################################################################################
@@ -483,17 +482,17 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
   if (measure == "OE") {
     if (verbose) message("Extracting/computing estimates of the total O:E ratio ...")
     
-    out$model <- pars.default$model.oe
-    
-    if (out$model == "normal/identity") {
+
+    if (pars.default$model.oe == "normal/identity") {
       g <- NULL
-    } else if (out$model == "normal/log" |  out$model == "poisson/log") {
+    } else if (pars.default$model.oe == "normal/log" |  pars.default$model.oe == "poisson/log") {
       g <- "log(OE)"
     } else {
-      stop(paste("Meta-analysis model currently not supported: '", out$model, '"', sep = ""))
+      stop(paste("Meta-analysis model currently not supported: '", pars.default$model.oe, '"', sep = ""))
     }
     
-    ds <- oecalc(OE = OE, OE.se = OE.se,
+    ds <- oecalc(OE = OE, 
+                 OE.se = OE.se,
                  OE.cilb = OE.cilb,
                  OE.ciub = OE.ciub,
                  OE.cilv = OE.cilv,
@@ -505,19 +504,31 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
                  Po = Po,
                  Po.se = Po.se,
                  Pe = Pe, 
-                 slab = slab, g = g, level = pars.default$level) 
+                 slab = slab, 
+                 g = g,
+                 level = pars.default$level) 
     
-    ## Assign study labels
-    out$slab <- rownames(ds)
     
-    ## Initial guess for number of studies in the meta-analysis
-    out$numstudies <- length(which(rowMeans(!is.na(ds)) == 1))
+    if (method == "BAYES") {
+      if (verbose) print("Performing Bayesian one-stage meta-analysis...")
+      return(run_Bayesian_MA_oe(call = match.call(),
+                                measure = measure,
+                                method = method,
+                                data = ds, 
+                                pars = pars.default, 
+                                n.chains = n.chains, 
+                                verbose = verbose, ...))
+
+    }
     
     if (method != "BAYES") { # Use of rma
+      ## Assign study labels
+      out$slab <- rownames(ds)
+      out$model <- pars.default$model.oe
       
       if (pars.default$model.oe == "normal/identity") {
-        if (verbose) print("Performing two-stage meta-analysis...")
-        fit <- rma(yi = ds$theta, sei = ds$theta.se, data = ds, method = method, test = test, slab = out$slab, ...) 
+        if (verbose) print("Performing a frequentist two-stage meta-analysis...")
+        fit <- metafor::rma(yi = ds$theta, sei = ds$theta.se, data = ds, method = method, test = test, slab = out$slab, ...) 
         preds <- predict(fit, level = pars.default$level)
         
         # The predict function from metafor uses a Normal distribution for prediction intervals, 
@@ -536,10 +547,10 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
         out$fit <- fit
         out$numstudies <- fit$k
         
-      } else if (pars.default$model.oe=="normal/log") {
-        if(verbose) print("Performing two-stage meta-analysis...")
-        fit <- rma(yi=ds$theta, sei=ds$theta.se, data=ds, method=method, test=test, slab=out$slab, ...) 
-        preds <- predict(fit, level=pars.default$level)
+      } else if (pars.default$model.oe == "normal/log") {
+        if (verbose) print("Performing two-stage meta-analysis...")
+        fit <- metafor::rma(yi = ds$theta, sei = ds$theta.se, data = ds, method = method, test = test, slab = out$slab, ...) 
+        preds <- predict(fit, level = pars.default$level)
         
         # The predict function from metafor uses a Normal distribution for prediction intervals, 
         # Here, we will use a Student T distribution instead
@@ -554,19 +565,31 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
         out$fit <- fit
         
         out$numstudies <- fit$k
-      } else if (pars.default$model.oe=="poisson/log") { 
-        if(verbose) print("Performing one-stage meta-analysis...")
-        if (method=="ML") { 
-          if (test=="knha") warning("The Sidik-Jonkman-Hartung-Knapp correction cannot be applied")
+      } else if (pars.default$model.oe == "poisson/log") { 
+        if (verbose) print("Performing one-stage meta-analysis...")
+        if (method == "ML") { 
+          if (test == "knha") warning("The Sidik-Jonkman-Hartung-Knapp correction cannot be applied")
           ds$Study <- out$slab
           ds$O <- round(ds$O)
-          fit <- glmer(O~1|Study, offset=log(E), family=poisson(link="log"), data=ds)
+          fit <- lme4::glmer(O~1|Study, offset = log(E), family = poisson(link="log"), data = ds)
           
-          # Omit 'Study' again from the dataset
-          ds <- ds[,-(colnames(ds)=="Study")]
+          # Extract the random effects
+          theta.ranef <- lme4::ranef(fit, drop = TRUE, condVar = TRUE)
+          #ds <- select(ds, -c("Study", "theta", "theta.se","theta.cilb", "theta.ciub"))
           
-          preds.ci <- confint(fit, level=pars.default$level, quiet=!verbose, ...)
-          predint <- calcPredInt(lme4::fixef(fit), sigma2=vcov(fit)[1,1], tau2=(as.data.frame(lme4::VarCorr(fit))["vcov"])[1,1], k=lme4::ngrps(fit), level=pars.default$level)
+          ia <- which(!is.na(ds$O) & !is.na(ds$E))
+          ds$theta.blup <- ds$theta.se.blup <- NA
+          ds$theta.blup[ia] <- as.numeric(theta.ranef$Study)
+          ds$theta.se.blup[ia] <- sqrt(attr(theta.ranef[[1]], "postVar"))
+          
+          preds.ci <- confint(fit, 
+                              level = pars.default$level, 
+                              quiet = !verbose, ...)
+          predint <- calcPredInt(lme4::fixef(fit), 
+                                 sigma2 = vcov(fit)[1,1], 
+                                 tau2 = (as.data.frame(lme4::VarCorr(fit))["vcov"])[1,1], 
+                                 k = lme4::ngrps(fit), 
+                                 level = pars.default$level)
           
           out$est    <- as.numeric(exp(lme4::fixef(fit)))
           out$ci.lb  <- exp(preds.ci["(Intercept)",1])
@@ -575,10 +598,10 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
           out$pi.ub  <- exp(predint$upper)
           
           out$fit <- fit
-          
           out$numstudies <- nobs(fit)
         } else if (method == "FE") { #one-stage fixed-effects meta-analysis
           fit <- glm(O~1, offset = log(E), family = poisson(link = "log"), data = ds)
+          
           preds.ci <- confint(fit, level = pars.default$level, quiet = !verbose, ...)
           
           out$est   <- as.numeric(exp(coefficients(fit)))
@@ -586,7 +609,6 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
           out$ci.ub <- out$pi.ub <- exp(preds.ci[2])
           
           out$fit <- fit
-          
           out$numstudies <- nobs(fit)
         } else {
           stop(paste("No implementation found for ", method, " estimation (model '", pars.default$model.oe, "')!", sep = ""))
@@ -594,16 +616,7 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
       } else {
         stop("Model not implemented yet!")
       }
-    } else {
-      if (verbose) print("Performing Bayesian one-stage meta-analysis...")
-      bayesma <- run_Bayesian_MA_oe(ds, pars = pars.default, n.chains = n.chains, verbose = verbose, ...)
-      out <- c(out, bayesma)
-      class(out) <- "valmeta"
-    }
-    
-    if ("Study" %in% colnames(ds)) {
-      ds <- ds[,-which(colnames(ds) == "Study")]
-    }
+    } 
     
     out$data <- ds
     
@@ -617,17 +630,17 @@ valmeta <- function(measure="cstat", cstat, cstat.se, cstat.cilb, cstat.ciub, cs
 #' @export
 print.valmeta <- function(x, ...) {
   text.stat <- attr(x$data,'estimand')
-  text.model <- if (x$method=="FE") "Fixed" else "Random"
-  text.ci <- if(x$method=="BAYES") "credibility" else "confidence"
-  text.pi <- if(x$method=="BAYES") "" else "(approximate)"
+  text.model <- if (x$method == "FE") "Fixed" else "Random"
+  text.ci <- if (x$method == "BAYES") "credibility" else "confidence"
+  text.pi <- if (x$method == "BAYES") "" else "(approximate)"
   
   
-  if (x$method!="FE") {
+  if (x$method != "FE") {
     cat(paste("Summary ", text.stat, " with ", x$level*100, "% ", text.ci, " and ", text.pi, " ", x$level*100, "% prediction interval:\n\n", sep=""))
     results <- c(Estimate=x$est, CIl=x$ci.lb, CIu=x$ci.ub, PIl=x$pi.lb, PIu=x$pi.ub)
   } else {
-    cat(paste("Summary ", text.stat, " with ", x$level*100, "% ", text.ci, " interval:\n\n", sep=""))
-    results <- c(Estimate=x$est, CIl=x$ci.lb, CIu=x$ci.ub)
+    cat(paste("Summary ", text.stat, " with ", x$level*100, "% ", text.ci, " interval:\n\n", sep = ""))
+    results <- c(Estimate = x$est, CIl = x$ci.lb, CIu = x$ci.ub)
   }
   print(results)
   cat("\n")
@@ -675,7 +688,12 @@ print.valmeta <- function(x, ...) {
 #' @method plot valmeta
 #' @export
 plot.valmeta <- function(x,  ...) {
-  yi.slab <- c(as.character(x$slab))
+  if (is.null(x$slab)) {
+    yi.slab <- rownames(x$data)
+  } else {
+    yi.slab <- c(as.character(x$slab))
+  }
+  
   yi <- c(x$data[,"theta"])
   ci.lb <- c(x$data[,"theta.cilb"])
   ci.ub <- c(x$data[,"theta.ciub"])
@@ -716,6 +734,7 @@ plot.valmeta <- function(x,  ...) {
 #' 
 #' @param x An object of class \code{"valmeta"}
 #' @param \ldots Additional arguments which are currently not used
+#' @return A \code{ggplot} object.
 #' 
 #' @details 
 #' Results are displayed for the estimated mean (\code{mu}) and standard-deviation (\code{tau}) of the meta-analysis model.
@@ -749,10 +768,8 @@ acplot.valmeta <- function(x, ...) {
     Parameter = c("mu.tobs", "bsTau"),
     Label = c("mu", "tau"))
   
-  S <- ggmcmc::ggs(x$fit$mcmc, par_labels = P, sort = FALSE)
-  S <- subset(S, S$ParameterOriginal %in% P$Parameter)
-  
-  ggmcmc::ggs_autocorrelation(S, greek = TRUE)
+  acplot(x$fit$mcmc, P = P, greek = TRUE, ...)
+
 }
 
 #' Plot the running means of a Bayesian meta-analysis model
@@ -761,6 +778,7 @@ acplot.valmeta <- function(x, ...) {
 #' 
 #' @param x An object of class \code{"valmeta"}
 #' @param \ldots Additional arguments which are currently not used
+#' @return A \code{ggplot} object.
 #' 
 #' @details 
 #' Results are displayed for the estimated mean (\code{mu}) and standard-deviation (\code{tau}) of the meta-analysis model.
@@ -786,18 +804,12 @@ rmplot.valmeta <- function(x, ...) {
   if (!("runjags" %in% class(x$fit))) {
     stop("The object 'x' does not represent a Bayesian analysis!")
   }
-  if (!requireNamespace("ggmcmc", quietly = TRUE)) {
-    stop("The package 'ggmcmc' is currently not installed!")
-  } 
   
   P <- data.frame(
     Parameter = c("mu.tobs", "bsTau"),
     Label = c("mu", "tau"))
   
-  S <- ggmcmc::ggs(x$fit$mcmc, par_labels = P, sort = FALSE)
-  S <- subset(S, S$ParameterOriginal %in% P$Parameter)
-  
-  ggmcmc::ggs_running(S, greek = TRUE)
+  rmplot(x$fit$mcmc, P = P, greek = TRUE, ...)
 }
 
 #' Plot the prior and posterior distribution of a meta-analysis model
@@ -812,6 +824,7 @@ rmplot.valmeta <- function(x, ...) {
 #' @param plot_type Character string to specify whether a density plot (\code{"dens"}) or 
 #' histogram (\code{"hist"}) should be displayed.
 #' @param \ldots Additional arguments which are currently not used
+#' @return A \code{ggplot} object.
 #' 
 #' @examples 
 #' \dontrun{
@@ -883,3 +896,42 @@ dplot.valmeta <- function(x, par, distr_type, plot_type = "dens", ...) {
   dplot(x$fit$mcmc, P = P, plot_type = plot_type, ...)
 }
 
+
+#' Gelman-Rubin-Brooks plot
+#' 
+#' This plot shows the evolution of Gelman and Rubin's shrink factor as the number of iterations increases. The code is adapted from
+#' the R package coda.
+#' 
+#' @param x An mcmc object
+#' @param confidence The coverage probability of the confidence interval for the potential scale reduction factor
+#' @param \ldots Additional arguments which are currently not used
+#' @return A \code{ggplot} object.
+#' 
+#' @examples 
+#' \dontrun{
+#' data(EuroSCORE)
+#' 
+#' # Meta-analysis of the concordance statistic
+#' fit <- valmeta(cstat=c.index, cstat.se=se.c.index, cstat.cilb=c.index.95CIl,
+#'                cstat.ciub=c.index.95CIu, N=n, O=n.events, 
+#'                data=EuroSCORE, method="BAYES", slab=Study)
+#' gelmanplot(fit)
+#' } 
+#' 
+#'             
+#' @author Thomas Debray <thomas.debray@gmail.com>
+#' 
+#' @return An object of class \code{ggplot}
+#' 
+#' @export
+gelmanplot.valmeta <- function(x, confidence = 0.95, ...) {
+  if (!("runjags" %in% class(x$fit))) {
+    stop("The object 'x' does not represent a Bayesian analysis!")
+  }
+  
+  P <- data.frame(
+    Parameter = c("mu.tobs", "bsTau"),
+    Label = c("mu", "tau"))
+  
+  return(gelmanplot(x$fit$mcmc, P = P, confidence = confidence, greek = TRUE, ...))
+}
\ No newline at end of file
